==> kdepim-addons_19.12.3.orig.tar.xz: kdepim-addons-19.12.3/kmail/editorconvertertextplugins/markdown/markdownlib/markdownconfiguredialog.cpp <==
/*
   Copyright (C) 2018-2019 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "markdownconfiguredialog.h"
#include "markdownconfigurewidget.h"
#include <KLocalizedString>
#include <QDesktopServices>
#include <QUrl>

MarkdownConfigureDialog::MarkdownConfigureDialog(QWidget *parent)
    : PimCommon::ConfigurePluginDialog(parent)
{
    setWindowTitle(i18n("Configure Markdown Plugin"));
    initLayout();
}

MarkdownConfigureDialog::~MarkdownConfigureDialog()
{
}

QWidget *MarkdownConfigureDialog::createLayout()
{
    mConfigureWidget = new MarkdownConfigureWidget(this);
    mConfigureWidget->setObjectName(QStringLiteral("configurewidget"));
    return mConfigureWidget;
}

void MarkdownConfigureDialog::save()
{
    mConfigureWidget->saveSettings();
}

void MarkdownConfigureDialog::load()
{
    mConfigureWidget->loadSettings();
}

void MarkdownConfigureDialog::reset()
{
    mConfigureWidget->resetSettings();
}

void MarkdownConfigureDialog::help()
{
    QDesktopServices::openUrl(QUrl(QStringLiteral("https://tools.ietf.org/html/rfc7763")));
}

==> kdepim-addons_20.08.3.orig.tar.xz: kdepim-addons-20.08.3/kmail/editorconvertertextplugins/markdown/markdownlib/markdownconfiguredialog.cpp <==
/*
   Copyright (C) 2018-2020 Laurent Montel <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "markdownconfiguredialog.h"
#include "markdownconfigurewidget.h"
#include <KLocalizedString>
#include <QDesktopServices>
#include <QUrl>

MarkdownConfigureDialog::MarkdownConfigureDialog(QWidget *parent)
    : PimCommon::ConfigurePluginDialog(parent)
{
    setWindowTitle(i18nc("@title:window", "Configure Markdown Plugin"));
    initLayout();
}

MarkdownConfigureDialog::~MarkdownConfigureDialog()
{
}

QWidget *MarkdownConfigureDialog::createLayout()
{
    mConfigureWidget = new MarkdownConfigureWidget(this);
    mConfigureWidget->setObjectName(QStringLiteral("configurewidget"));
    return mConfigureWidget;
}

void MarkdownConfigureDialog::save()
{
    mConfigureWidget->saveSettings();
}

void MarkdownConfigureDialog::load()
{
    mConfigureWidget->loadSettings();
}

void MarkdownConfigureDialog::reset()
{
    mConfigureWidget->resetSettings();
}

void MarkdownConfigureDialog::help()
{
    QDesktopServices::openUrl(QUrl(QStringLiteral("https://tools.ietf.org/html/rfc7763")));
}
